# Statistics

Statistical analysis tools for confidence intervals, significance testing, effect sizes, and power analysis.

## Confidence Intervals

### bootstrap_ci

::: rotalabs_eval.statistics.confidence.bootstrap_ci
    options:
      show_source: true

### bootstrap_ci_bca

::: rotalabs_eval.statistics.confidence.bootstrap_ci_bca
    options:
      show_source: true

### analytical_ci_mean

::: rotalabs_eval.statistics.confidence.analytical_ci_mean
    options:
      show_source: true

### analytical_ci_proportion

::: rotalabs_eval.statistics.confidence.analytical_ci_proportion
    options:
      show_source: true

### compare_cis

::: rotalabs_eval.statistics.confidence.compare_cis
    options:
      show_source: true

## Significance Tests

### SignificanceResult

::: rotalabs_eval.statistics.significance.SignificanceResult
    options:
      show_source: true

### paired_ttest

::: rotalabs_eval.statistics.significance.paired_ttest
    options:
      show_source: true

### mcnemar_test

::: rotalabs_eval.statistics.significance.mcnemar_test
    options:
      show_source: true

### wilcoxon_signed_rank

::: rotalabs_eval.statistics.significance.wilcoxon_signed_rank
    options:
      show_source: true

### bootstrap_significance

::: rotalabs_eval.statistics.significance.bootstrap_significance
    options:
      show_source: true

### choose_test

::: rotalabs_eval.statistics.significance.choose_test
    options:
      show_source: true

## Effect Sizes

### EffectSizeResult

::: rotalabs_eval.statistics.effect_size.EffectSizeResult
    options:
      show_source: true

### cohens_d

::: rotalabs_eval.statistics.effect_size.cohens_d
    options:
      show_source: true

### hedges_g

::: rotalabs_eval.statistics.effect_size.hedges_g
    options:
      show_source: true

### odds_ratio

::: rotalabs_eval.statistics.effect_size.odds_ratio
    options:
      show_source: true

### relative_improvement

::: rotalabs_eval.statistics.effect_size.relative_improvement
    options:
      show_source: true

## Power Analysis

### PowerAnalysisResult

::: rotalabs_eval.statistics.power.PowerAnalysisResult
    options:
      show_source: true

### sample_size_for_mean_diff

::: rotalabs_eval.statistics.power.sample_size_for_mean_diff
    options:
      show_source: true

### sample_size_for_proportion_diff

::: rotalabs_eval.statistics.power.sample_size_for_proportion_diff
    options:
      show_source: true

### compute_power

::: rotalabs_eval.statistics.power.compute_power
    options:
      show_source: true
